@@ -1,5 +1,5 @@
-from workplace_extractor.Extractors import PostExtractor, CommentExtractor, GroupExtractor, MembersExtractor
-from workplace_extractor.Extractors import PersonExtractor, InteractionExtractor, EventExtractor
+from .Extractors import PostExtractor, CommentExtractor, GroupExtractor, MembersExtractor
+from .Extractors import PersonExtractor, InteractionExtractor, EventExtractor
 
 # import pickle
 import sys
@@ -8,6 +8,7 @@ import logging
 import asyncio
 import aiohttp
 import pandas as pd
+import random
 
 
 class AuthTokenError(Exception):
@@ -21,7 +22,7 @@ class Extractor(object):
         self.token = kwargs.get('access_token')
 
         self.export = kwargs.get('export')
-        self.export_file = kwargs.get('export_file')
+        self.export_file = f'{kwargs.get("export_file")}.xlsx'
         self.export_folder = kwargs.get('export_folder')
 
         self.export_content = kwargs.get('export_content', False)
@@ -32,6 +33,9 @@ class Extractor(object):
         self.graph_url = kwargs.get('graph_url')
         self.scim_url = kwargs.get('scim_url')
 
+        self.update_task_progress_func = kwargs.get('update_task_progress_func', None)
+        self.celery_task = kwargs.get('celery_task', None)
+
         if kwargs.get('hashtags', '') is not None:
             self.hashtags = [hashtag.lower() for hashtag in kwargs.get('hashtags', '').replace('#', '').split(',')]
         else:
@@ -40,7 +44,7 @@ class Extractor(object):
             # optional options
         args = ['since', 'until', 'post_id', 'group_id', 'event_id', 'author_id', 'feed_id',
                 'active_only', 'create_ranking', 'create_gexf', 'node_attributes', 'additional_node_attributes',
-                'joining_column']
+                'joining_column', 'people_attributes_file', 'people_attributes_join']
         for key, value in kwargs.items():
             if key in args:
                 setattr(self, key, value)
@@ -60,8 +64,6 @@ class Extractor(object):
 
     async def _extract(self):
 
-        return {'teste': 2}
-
         await self.init()
 
         extractor = None
@@ -83,8 +85,7 @@ class Extractor(object):
         await extractor.extract()
 
         nodes_pd = extractor.nodes.to_pandas(self)
-        nodes_pd.replace(to_replace=[r"\\t|\\n|\\r", "\t|\n|\r"], value=[" ", " "], regex=True) \
-                .to_excel(f'{self.export_folder}{self.export_file}', sheet_name='Results', index=False)
+        nodes_pd.replace(to_replace=[r"\\t|\\n|\\r", "\t|\n|\r"], value=[" ", " "], regex=True)
 
         return nodes_pd
 
@@ -107,6 +108,10 @@ class Extractor(object):
             return await call(url, session, **kwargs)
 
     async def fetch_url(self, url, session, api='', **kwargs):
+
+        if random.randint(1, 100) == 100:
+            self.update_task_progress_func(self.celery_task, url=url, message='random log')
+
         # to prevent GRAPH bug with infinite recursion
         if kwargs.get('recursion', 0) > self.max_recursion:
             logging.error('TOO MUCH RECURSION - ignoring next pages')
